PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/analysis/plots.py File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Namespaces | Variables
plots.py File Reference

## Namespaces
| pawpyseed.analysis.plots

## Variables
| pawpyseed.analysis.plots.f = open('tst.txt', 'r')
| pawpyseed.analysis.plots.myd = yaml.load(f)
| pawpyseed.analysis.plots.yh = myd['yh']
| pawpyseed.analysis.plots.r = myd['r']
| pawpyseed.analysis.plots.label